@@ -38,15 +38,13 @@ class YoloPredictor:
         model.save = self.save
         model.show = self.show
         self.model = model
+        return model
 
-    def predict(self, image, yaml_file=None):
+    def yolo_predictor(self, image, yaml_file=None):
         return self.model.predict(image, yaml_file=yaml_file)
 
 
 if __name__ == "__main__":
-    predictor = YoloPredictor(
-        model_type="yolov8", model_path="yolov8n.pt", device="cpu", image_size=640
-    )
-
+    model = YoloPredictor(model_type="yolov8", model_path="yolov8n.pt", device="cpu", image_size=640)
     image = "data/highway.jpg"
-    result = predictor.predict(image)
+    result = model.yolo_predictor(image)
